@@ -1,6 +1,8 @@
 #include "adw-demo-page-view-switcher.h"
 
-#include "adw-view-switcher-demo-dialog.h"
+#include <glib/gi18n.h>
+
+#include "adw-view-switcher-demo-window.h"
 
 struct _AdwDemoPageViewSwitcher
 {
@@ -12,7 +14,11 @@ G_DEFINE_FINAL_TYPE (AdwDemoPageViewSwitcher, adw_demo_page_view_switcher, ADW_T
 static void
 demo_run_cb (AdwDemoPageViewSwitcher *self)
 {
-  adw_dialog_present (adw_view_switcher_demo_dialog_new (), GTK_WIDGET (self));
+  AdwViewSwitcherDemoWindow *window = adw_view_switcher_demo_window_new ();
+  GtkRoot *root = gtk_widget_get_root (GTK_WIDGET (self));
+
+  gtk_window_set_transient_for (GTK_WINDOW (window), GTK_WINDOW (root));
+  gtk_window_present (GTK_WINDOW (window));
 }
 
 static void
